@@ -9,7 +9,7 @@ will:
 
 """
 
-from __future__ import absolute_import
+from __future__ import absolute_import, annotations
 
 import itertools
 
